eprllib.ActionFunctions.window_shading_control — eprllib: use EnergyPlus as an environment for DRL control

Skip to main content
`Ctrl`+`K`

# eprllib.ActionFunctions.window_shading_control

## Window Shading Control

The window shading control allow two actuators: Control Mode and Slat Angle.

The following settings are valid and must be used:

  - -1.0: No shading device.

  - 0.0: Shading device is off (applies to shades and blinds).

  - 1.0: Interior shade is on.

  - 2.0: Glazing is switched to a darker state (switchable glazings only).

  - 3.0: Exterior shade is on.

  - 4.0: Exterior screen is on.

  - 6.0: Interior blind is on.

  - 7.0: Exterior blind is on.

  - 8.0: Between-glass shade is on.

  - 9.0: Between-glass blind is on.

Classes

`shading_actions`(action_fn_config) |